; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
;

;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;
[Command]
name = "invincibleartoffirewheel"
command = ~D, DF, F, D, DF, F, c
time = 20

[Command]
name = "jumpingslashattack"
command = ~D, DB, B, D, DB, B, c
time = 20

[Command]
name = "swordextension"
command = ~D, DF, F, D, DF, F, z
time = 20

[Command]
name = "phantomdouble"
command = ~D, DB, B, D, DB, B, z
time = 20

;-| Special Motions |------------------------------------------------------
[Command]
name = "artoffirewheel_c"
command = ~D, DB, B, c
time = 15

[Command]
name = "firedragonball_c"
command = ~D, DF, F, c
time = 15

[Command]
name = "windmillstar_c"
command = ~15$B, F, c
time = 30

[Command]
name = "vacuumwaveart_c"
command = ~D, DF, F, c
time=15

[Command]
name="kickflip_a"
command = ~D, DB, B, a
time = 20

[Command]
name="kickflip_b"
command = ~D, DB, B, b
time = 20

[Command]
name = "shuriken_c"
command = c
time = 15

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]
;----------------------------------------------------------------------------
;Phantom Doubles
[State -1, PhantomDouble]
type = ChangeState
value = 3020
triggerall = var(0) < 2
triggerall = statetype = S
trigger1 = command ="phantomdouble"
trigger1 = ctrl
trigger1 = Power >= 1000
;----------------------------------------------------------------------------
;Sword Extension
[State -1, swordextension]
type = ChangeState
value = 3010
triggerall = command = "swordextension"
triggerall = statetype = S
;triggerall = p2movetype != H
trigger1 = ctrl
trigger1 = Power >= 1000
trigger1 = var(3) = 0
trigger2 = MoveContact
trigger2 = StateNo != 950
trigger2 = StateNo != 955
trigger2 = StateNo != 960
trigger2 = StateNo != 1000
trigger2 = StateNo != 1001
trigger2 = StateNo != 1010
trigger2 = StateNo != 1011
trigger2 = StateNo != 1020
trigger2 = StateNo != 1021
trigger2 = StateNo != 1100
trigger2 = StateNo != 1101
trigger2 = StateNo != 1110
trigger2 = StateNo != 1111
trigger2 = StateNo != 1120
trigger2 = StateNo != 1121
trigger2 = StateNo != 1140
trigger2 = StateNo != 1150
trigger2 = StateNo != 1160
trigger2 = StateNo != 3000
trigger2 = StateNo != 3001
trigger2 = StateNo != 3010
trigger2 = StateNo != 3011
trigger2 = StateNo != 3020
trigger2 = StateNo != 3025
trigger2 = StateNo != 3030
trigger2 = StateNo != 3050
trigger2 = StateNo != 3100
trigger2 = StateNo != 3110
trigger2 = StateNo != 3120
;----------------------------------------------------------------------------
;Invincible Art of Fire Wheel
[State -1, invincibleartoffirewheel]
type = ChangeState
value = 3000
triggerall = command="invincibleartoffirewheel"
triggerall = statetype = S
triggerall = p2movetype != H
trigger1 = ctrl
trigger1 = Power = 3000
trigger2 = MoveContact
trigger2 = StateNo != 950
trigger2 = StateNo != 955
trigger2 = StateNo != 960
trigger2 = StateNo != 1000
trigger2 = StateNo != 1001
trigger2 = StateNo != 1010
trigger2 = StateNo != 1011
trigger2 = StateNo != 1020
trigger2 = StateNo != 1021
trigger2 = StateNo != 1100
trigger2 = StateNo != 1101
trigger2 = StateNo != 1110
trigger2 = StateNo != 1111
trigger2 = StateNo != 1120
trigger2 = StateNo != 1121
trigger2 = StateNo != 1140
trigger2 = StateNo != 1150
trigger2 = StateNo != 1160
trigger2 = StateNo != 3000
trigger2 = StateNo != 3001
trigger2 = StateNo != 3010
trigger2 = StateNo != 3011
trigger2 = StateNo != 3020
trigger2 = StateNo != 3025
trigger2 = StateNo != 3030
trigger2 = StateNo != 3050
trigger2 = StateNo != 3100
trigger2 = StateNo != 3110
trigger2 = StateNo != 3120
;----------------------------------------------------------------------------
;Jumping Slash Attack
[State -1, jumpingslashattack]
type = ChangeState
value = 3005
triggerall = command="jumpingslashattack"
triggerall = statetype = A
triggerall = p2movetype != H
trigger1 = ctrl
trigger1 = Power = 3000
trigger2 = MoveContact
trigger2 = StateNo != 950
trigger2 = StateNo != 955
trigger2 = StateNo != 960
trigger2 = StateNo != 1000
trigger2 = StateNo != 1001
trigger2 = StateNo != 1010
trigger2 = StateNo != 1011
trigger2 = StateNo != 1020
trigger2 = StateNo != 1021
trigger2 = StateNo != 1100
trigger2 = StateNo != 1101
trigger2 = StateNo != 1110
trigger2 = StateNo != 1111
trigger2 = StateNo != 1120
trigger2 = StateNo != 1121
trigger2 = StateNo != 1140
trigger2 = StateNo != 1150
trigger2 = StateNo != 1160
trigger2 = StateNo != 3000
trigger2 = StateNo != 3001
trigger2 = StateNo != 3010
trigger2 = StateNo != 3011
trigger2 = StateNo != 3020
trigger2 = StateNo != 3025
trigger2 = StateNo != 3030
trigger2 = StateNo != 3050
trigger2 = StateNo != 3100
trigger2 = StateNo != 3110
trigger2 = StateNo != 3120

;----------------------------------------------------------------------------
;Kick Flip
[State -1, kickflip]
type = ChangeState
value = 1060
triggerall = statetype = S
triggerall = p2movetype != H
triggerall = p2bodydist X < 10
triggerall = ctrl
trigger1 = command = "kickflip_a"
trigger2 = command = "kickflip_b"
trigger3 = MoveContact
trigger3 = StateNo != 950
trigger3 = StateNo != 955
trigger3 = StateNo != 960
trigger3 = StateNo != 1000
trigger3 = StateNo != 1001
trigger3 = StateNo != 1010
trigger3 = StateNo != 1011
trigger3 = StateNo != 1020
trigger3 = StateNo != 1021
trigger3 = StateNo != 1100
trigger3 = StateNo != 1101
trigger3 = StateNo != 1110
trigger3 = StateNo != 1111
trigger3 = StateNo != 1120
trigger3 = StateNo != 1121
trigger3 = StateNo != 1140
trigger3 = StateNo != 1150
trigger3 = StateNo != 1160
trigger3 = StateNo != 3000
trigger3 = StateNo != 3001
trigger3 = StateNo != 3010
trigger3 = StateNo != 3011
trigger3 = StateNo != 3020
trigger3 = StateNo != 3025
trigger3 = StateNo != 3030
trigger3 = StateNo != 3050
trigger3 = StateNo != 3100
trigger3 = StateNo != 3110
trigger3 = StateNo != 3120
;----------------------------------------------------------------------------
;vacuumwaveart_c (Standing);
[State -1, windmillstar_c]
type = ChangeState
value = 1050
triggerall = command="vacuumwaveart_c"
triggerall=numproj =0
triggerall = statetype = S
triggerall = p2movetype != H
trigger1 = ctrl
trigger2 = MoveContact
trigger2 = StateNo != 950
trigger2 = StateNo != 955
trigger2 = StateNo != 960
trigger2 = StateNo != 1000
trigger2 = StateNo != 1001
trigger2 = StateNo != 1010
trigger2 = StateNo != 1011
trigger2 = StateNo != 1020
trigger2 = StateNo != 1021
trigger2 = StateNo != 1100
trigger2 = StateNo != 1101
trigger2 = StateNo != 1110
trigger2 = StateNo != 1111
trigger2 = StateNo != 1120
trigger2 = StateNo != 1121
trigger2 = StateNo != 1140
trigger2 = StateNo != 1150
trigger2 = StateNo != 1160
trigger2 = StateNo != 3000
trigger2 = StateNo != 3001
trigger2 = StateNo != 3010
trigger2 = StateNo != 3011
trigger2 = StateNo != 3020
trigger2 = StateNo != 3025
trigger2 = StateNo != 3030
trigger2 = StateNo != 3050
trigger2 = StateNo != 3100
trigger2 = StateNo != 3110
trigger2 = StateNo != 3120
;----------------------------------------------------------------------------
;windmillstar_c (Standing)
[State -1, windmillstar_c]
type = ChangeState
value = 1040
triggerall = command="windmillstar_c"
triggerall=numproj =0
triggerall = statetype = S
triggerall = p2movetype != H
trigger1 = ctrl
trigger2 = MoveContact
trigger2 = StateNo != 950
trigger2 = StateNo != 955
trigger2 = StateNo != 960
trigger2 = StateNo != 1000
trigger2 = StateNo != 1001
trigger2 = StateNo != 1010
trigger2 = StateNo != 1011
trigger2 = StateNo != 1020
trigger2 = StateNo != 1021
trigger2 = StateNo != 1100
trigger2 = StateNo != 1101
trigger2 = StateNo != 1110
trigger2 = StateNo != 1111
trigger2 = StateNo != 1120
trigger2 = StateNo != 1121
trigger2 = StateNo != 1140
trigger2 = StateNo != 1150
trigger2 = StateNo != 1160
trigger2 = StateNo != 3000
trigger2 = StateNo != 3001
trigger2 = StateNo != 3010
trigger2 = StateNo != 3011
trigger2 = StateNo != 3020
trigger2 = StateNo != 3025
trigger2 = StateNo != 3030
trigger2 = StateNo != 3050
trigger2 = StateNo != 3100
trigger2 = StateNo != 3110
trigger2 = StateNo != 3120
;----------------------------------------------------------------------------
;Fire Dragon Ball (In Air)
[State -1, firedragonball_c]
type = ChangeState
value = 1030
triggerall = command="firedragonball_c"
triggerall=numproj =0
triggerall = statetype = A
triggerall = p2movetype != H
trigger1 = ctrl
trigger2 = MoveContact
trigger2 = StateNo != 950
trigger2 = StateNo != 955
trigger2 = StateNo != 960
trigger2 = StateNo != 1000
trigger2 = StateNo != 1001
trigger2 = StateNo != 1010
trigger2 = StateNo != 1011
trigger2 = StateNo != 1020
trigger2 = StateNo != 1021
trigger2 = StateNo != 1100
trigger2 = StateNo != 1101
trigger2 = StateNo != 1110
trigger2 = StateNo != 1111
trigger2 = StateNo != 1120
trigger2 = StateNo != 1121
trigger2 = StateNo != 1140
trigger2 = StateNo != 1150
trigger2 = StateNo != 1160
trigger2 = StateNo != 3000
trigger2 = StateNo != 3001
trigger2 = StateNo != 3010
trigger2 = StateNo != 3011
trigger2 = StateNo != 3020
trigger2 = StateNo != 3025
trigger2 = StateNo != 3030
trigger2 = StateNo != 3050
trigger2 = StateNo != 3100
trigger2 = StateNo != 3110
trigger2 = StateNo != 3120
;---------------------------------------------------------------------------
;Art Of Fire Wheel (Standing)
[State -1, artoffirewheel_c]
type = ChangeState
value = 1020
triggerall = command="artoffirewheel_c"
triggerall=numproj =0
triggerall = statetype = S || statetype = C
triggerall = p2movetype != H
trigger1 = ctrl
trigger2 = MoveContact
trigger2 = StateNo != 950
trigger2 = StateNo != 955
trigger2 = StateNo != 960
trigger2 = StateNo != 1000
trigger2 = StateNo != 1001
trigger2 = StateNo != 1010
trigger2 = StateNo != 1011
trigger2 = StateNo != 1020
trigger2 = StateNo != 1021
trigger2 = StateNo != 1100
trigger2 = StateNo != 1101
trigger2 = StateNo != 1110
trigger2 = StateNo != 1111
trigger2 = StateNo != 1120
trigger2 = StateNo != 1121
trigger2 = StateNo != 1140
trigger2 = StateNo != 1150
trigger2 = StateNo != 1160
trigger2 = StateNo != 3000
trigger2 = StateNo != 3001
trigger2 = StateNo != 3010
trigger2 = StateNo != 3011
trigger2 = StateNo != 3020
trigger2 = StateNo != 3025
trigger2 = StateNo != 3030
trigger2 = StateNo != 3050
trigger2 = StateNo != 3100
trigger2 = StateNo != 3110
trigger2 = StateNo != 3120
;----------------------------------------------------------------------------
;Shuriken_C (Standing)
[State -1, shuriken_c]
type = ChangeState
value = 1010
triggerall = command="shuriken_c"
triggerall=numproj =0
triggerall = statetype = S
triggerall = p2movetype != H
trigger1 = ctrl
trigger2 = MoveContact
trigger2 = StateNo != 950
trigger2 = StateNo != 955
trigger2 = StateNo != 960
trigger2 = StateNo != 1000
trigger2 = StateNo != 1001
trigger2 = StateNo != 1010
trigger2 = StateNo != 1011
trigger2 = StateNo != 1020
trigger2 = StateNo != 1021
trigger2 = StateNo != 1100
trigger2 = StateNo != 1101
trigger2 = StateNo != 1110
trigger2 = StateNo != 1111
trigger2 = StateNo != 1120
trigger2 = StateNo != 1121
trigger2 = StateNo != 1140
trigger2 = StateNo != 1150
trigger2 = StateNo != 1160
trigger2 = StateNo != 3000
trigger2 = StateNo != 3001
trigger2 = StateNo != 3010
trigger2 = StateNo != 3011
trigger2 = StateNo != 3020
trigger2 = StateNo != 3025
trigger2 = StateNo != 3030
trigger2 = StateNo != 3050
trigger2 = StateNo != 3100
trigger2 = StateNo != 3110
trigger2 = StateNo != 3120
;----------------------------------------------------------------------------
;Shuriken_C (In Air)
[State -1, shuriken_c]
type = ChangeState
value = 1011
triggerall = command="shuriken_c"
triggerall=numproj =0
triggerall = statetype = A
triggerall = p2movetype != H
trigger1 = ctrl
trigger2 = MoveContact
trigger2 = StateNo != 950
trigger2 = StateNo != 955
trigger2 = StateNo != 960
trigger2 = StateNo != 1000
trigger2 = StateNo != 1001
trigger2 = StateNo != 1010
trigger2 = StateNo != 1011
trigger2 = StateNo != 1020
trigger2 = StateNo != 1021
trigger2 = StateNo != 1100
trigger2 = StateNo != 1101
trigger2 = StateNo != 1110
trigger2 = StateNo != 1111
trigger2 = StateNo != 1120
trigger2 = StateNo != 1121
trigger2 = StateNo != 1140
trigger2 = StateNo != 1150
trigger2 = StateNo != 1160
trigger2 = StateNo != 3000
trigger2 = StateNo != 3001
trigger2 = StateNo != 3010
trigger2 = StateNo != 3011
trigger2 = StateNo != 3020
trigger2 = StateNo != 3025
trigger2 = StateNo != 3030
trigger2 = StateNo != 3050
trigger2 = StateNo != 3100
trigger2 = StateNo != 3110
trigger2 = StateNo != 3120
;---------------------------------------------------------------------------
;Shuriken_C (Crouching)
[State -1, shuriken_c]
type = ChangeState
value = 1012
triggerall = command="shuriken_c"
triggerall=numproj =0
triggerall = statetype = C
triggerall = p2movetype != H
trigger1 = ctrl
trigger2 = MoveContact
trigger2 = StateNo != 950
trigger2 = StateNo != 955
trigger2 = StateNo != 960
trigger2 = StateNo != 1000
trigger2 = StateNo != 1001
trigger2 = StateNo != 1010
trigger2 = StateNo != 1011
trigger2 = StateNo != 1020
trigger2 = StateNo != 1021
trigger2 = StateNo != 1100
trigger2 = StateNo != 1101
trigger2 = StateNo != 1110
trigger2 = StateNo != 1111
trigger2 = StateNo != 1120
trigger2 = StateNo != 1121
trigger2 = StateNo != 1140
trigger2 = StateNo != 1150
trigger2 = StateNo != 1160
trigger2 = StateNo != 3000
trigger2 = StateNo != 3001
trigger2 = StateNo != 3010
trigger2 = StateNo != 3011
trigger2 = StateNo != 3020
trigger2 = StateNo != 3025
trigger2 = StateNo != 3030
trigger2 = StateNo != 3050
trigger2 = StateNo != 3100
trigger2 = StateNo != 3110
trigger2 = StateNo != 3120
;---------------------------------------------------------------------------


;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl


;===========================================================================
;---------------------------------------------------------------------------
;Stand Light Punch
;p`
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = command = "x"
;triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = time = 2

;---------------------------------------------------------------------------
;Stand Medium Punch
;p`
[State -1, Stand Medium Punch]
type = ChangeState
value = 205
triggerall = command = "y"
;triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 205
trigger2 = time = 4

;---------------------------------------------------------------------------
;Stand Sword
;p`
[State -1, Stand Sword]
type = ChangeState
value = 210
triggerall = command = "z"
;triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 210
trigger2 = time = 6

;---------------------------------------------------------------------------
;Stand Light Kick
;LbN
[State -1, Stand Light Kick]
type = ChangeState
value = 215
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 215
trigger2= time = 2

;---------------------------------------------------------------------------
;Standing Medium Kick
;LbN
[State -1, Standing Medium Kick]
type = ChangeState
value = 220
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 215
trigger2= time = 2

;---------------------------------------------------------------------------
;Taunt
;
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "start"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Light Punch
;Ⴊݎp`
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 400
trigger2 = time = 2
;---------------------------------------------------------------------------
;Crouching Medium Punch
;Ⴊ݋p`
[State -1, Crouching Medium Punch]
type = ChangeState
value = 405
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 405
trigger2 = time = 4
;---------------------------------------------------------------------------
;Crouching Sword Attack
;Ⴊ݋p`
[State -1, Crouching Strong Punch]
type = ChangeState
value = 410
triggerall = command = "z"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 410
trigger2 = time = 6
;---------------------------------------------------------------------------
;Crouching Light Kick
;ႪݎLbN
[State -1, Crouching Light Kick]
type = ChangeState
value = 400
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 400
trigger2 = time = 2

;---------------------------------------------------------------------------
;Crouching Strong Kick
;Ⴊ݋LbN
[State -1, Crouching Strong Kick]
type = ChangeState
value = 405
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 405
trigger2 = time = 4

;---------------------------------------------------------------------------
;Jump Light Punch
;󒆎p`
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = time = 2

;---------------------------------------------------------------------------
;Jump Medium Punch
[State -1, Jump Medium Punch]
type = ChangeState
value = 605
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 605
trigger2 = time = 4

;---------------------------------------------------------------------------
;Jump Sword Attack
[State -1, Jump Strong Punch]
type = ChangeState
value = 610
triggerall = command = "z"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 610
trigger2 = time = 6

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jump Medium Kick
;󒆋LbN
[State -1, Jump Strong Kick]
type = ChangeState
value = 635
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 ;jump_x or jump_a
trigger2 = movecontact
;---------------------------------------------------------------------------
;Wall Jump
[State -1, Wall Jump]
type = ChangeState
value = 800
trigger1 = statetype = A
trigger1 = backedgebodydist <= 5
trigger1 = Vel X < 0
trigger1 = command = "holdfwd"
trigger1 = ctrl
trigger2 = statetype = A
trigger2 = frontedgebodydist <= 5
trigger2 = Vel X > 0
trigger2 = command = "holdback"
trigger2 = ctrl
;----------------------------------------------------------------------------